==> abcl-0.0.9.tar.gz: abcl-0.0.9/src/org/armedbear/lisp/Return.java <==
/*
 * Return.java
 *
 * Copyright (C) 2002-2005 Peter Graves
 * $Id: Return.java,v 1.10 2005/06/22 23:32:06 piso Exp $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.armedbear.lisp;

public final class Return extends ConditionThrowable
{
    public final LispObject tag;
    public final LispObject block;
    public final LispObject result;

    public Return(LispObject tag, LispObject block, LispObject result)
    {
        this.tag = tag;
        this.block = block;
        this.result = result;
    }

    public Return(LispObject tag, LispObject result)
    {
        this.tag = tag;
        this.block = null;
        this.result = result;
    }

    public LispObject getTag()
    {
        return tag;
    }

    public LispObject getBlock()
    {
        return block;
    }

    public LispObject getResult()
    {
        return result;
    }

    public LispObject getCondition()
    {
        try {
            StringBuffer sb = new StringBuffer("No block named ");
            sb.append(tag.writeToString());
            sb.append(" is currently visible.");
            return new ControlError(sb.toString());
        }
        catch (Throwable t) {
            Debug.trace(t);
            return new Condition();
        }
    }
}

==> abcl-0.0.10.tar.gz: abcl-0.0.10/src/org/armedbear/lisp/Return.java <==
/*
 * Return.java
 *
 * Copyright (C) 2002-2005 Peter Graves
 * $Id: Return.java,v 1.11 2005/11/01 01:35:40 piso Exp $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.armedbear.lisp;

public final class Return extends ConditionThrowable
{
    public final LispObject tag;
    public final LispObject block;
    public final LispObject result;

    public Return(LispObject tag, LispObject block, LispObject result)
    {
        this.tag = tag;
        this.block = block;
        this.result = result;
    }

    public Return(LispObject tag, LispObject result)
    {
        this.tag = tag;
        this.block = null;
        this.result = result;
    }

    public LispObject getTag()
    {
        return tag;
    }

    public LispObject getBlock()
    {
        return block;
    }

    public LispObject getResult()
    {
        return result;
    }

    public LispObject getCondition() throws ConditionThrowable
    {
        try {
            FastStringBuffer sb = new FastStringBuffer("No block named ");
            sb.append(tag.writeToString());
            sb.append(" is currently visible.");
            return new ControlError(sb.toString());
        }
        catch (Throwable t) {
            Debug.trace(t);
            return new Condition();
        }
    }
}
